# Generated by Django 3.1 on 2021-05-23 11:09

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Region',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=200, unique=True)),
                ('capital', models.CharField(blank=True, max_length=200, null=True, unique=True)),
                ('districts', models.PositiveIntegerField(blank=True, null=True)),
                ('postcode', models.CharField(blank=True, max_length=50, null=True, unique=True)),
                ('zone', models.CharField(blank=True, max_length=100, null=True)),
                ('population', models.IntegerField(blank=True, null=True)),
                ('area', models.CharField(blank=True, max_length=50, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='District',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=100, unique=True)),
                ('population', models.IntegerField(blank=True, null=True)),
                ('region', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='mikoa.region')),
            ],
        ),
    ]



# Generated by Django 3.1 on 2021-05-23 11:14

import csv
from django.db import migrations
from django.apps.registry import apps

class Migration(migrations.Migration):

    dependencies = [
        ('mikoa', '0001_initial'),
    ]

    def load_data(self, schema_editor):
        Region = apps.get_model('mikoa', 'Region')
        District = apps.get_model('mikoa', 'District')

        mikoa = open('mikoa/mikoa.csv')
        wilaya = open('mikoa/wilaya.csv')

        mikoa_reader = csv.reader(mikoa)
        wilaya_reader = csv.reader(wilaya)

        Region.objects.all().delete()
        District.objects.all().delete()

        next(mikoa_reader)
        for row in mikoa_reader:

            r, created = Region.objects.get_or_create(
                id = row[0],
                name = row[1],
                capital = row[2],
                districts = row[3],
                area = row[4],
                population = row[5],
                postcode = row[6],
                zone = row[7]
            )

        next(wilaya_reader)
        for row in wilaya_reader:

            r, created = District.objects.get_or_create(
                id = row[0],
                region_id = row[1],
                name = row[2],
                population = row[3],
            )

    operations = [
        migrations.RunPython(
            load_data,
            migrations.RunPython.noop
        ),
    ]



from django.db import models

class Region(models.Model):
    name = models.CharField(max_length=200, unique=True)
    capital = models.CharField(max_length=200, unique=True, blank=True, null=True)
    districts = models.PositiveIntegerField(blank=True, null=True)
    postcode = models.CharField(max_length=50, unique=True, blank=True, null=True)
    zone = models.CharField(max_length=100, blank=True, null=True)
    population = models.IntegerField(blank=True, null=True)
    area = models.CharField(max_length=50, blank=True, null=True)

    def __str__(self):
        return str(self.name)


class District(models.Model):
    region = models.ForeignKey(Region, on_delete=models.CASCADE)
    name = models.CharField(max_length=100, unique=True)
    population = models.IntegerField(blank=True, null=True)

    def __str__(self):
        return str(self.name)


import os
from setuptools import find_packages, setup

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name="django-mikoa",
    version="0.0.1",
    packages=find_packages(),
    include_package_data=True,
    author="Medson Naftali",
    author_email="medsonnaftal@gmail.com",
    description="Django app for Tanzania Regions and Districts",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/devmed/django-mikoa",
    project_urls={
        "Bug Tracker": "https://github.com/devmed/django-mikoa/issues",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)